==> certmanager-model-v1alpha2-6.0.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/CertificateRequestSpecBuilder.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CertificateRequestSpecBuilder extends CertificateRequestSpecFluentImpl<CertificateRequestSpecBuilder> implements VisitableBuilder<CertificateRequestSpec,CertificateRequestSpecBuilder>{
  public CertificateRequestSpecBuilder() {
    this(false);
  }
  public CertificateRequestSpecBuilder(Boolean validationEnabled) {
    this(new CertificateRequestSpec(), validationEnabled);
  }
  public CertificateRequestSpecBuilder(CertificateRequestSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public CertificateRequestSpecBuilder(CertificateRequestSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CertificateRequestSpec(), validationEnabled);
  }
  public CertificateRequestSpecBuilder(CertificateRequestSpecFluent<?> fluent,CertificateRequestSpec instance) {
    this(fluent, instance, false);
  }
  public CertificateRequestSpecBuilder(CertificateRequestSpecFluent<?> fluent,CertificateRequestSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCsr(instance.getCsr()); 
    fluent.withDuration(instance.getDuration()); 
    fluent.withIsCA(instance.getIsCA()); 
    fluent.withIssuerRef(instance.getIssuerRef()); 
    fluent.withUsages(instance.getUsages()); 
    this.validationEnabled = validationEnabled; 
  }
  public CertificateRequestSpecBuilder(CertificateRequestSpec instance) {
    this(instance,false);
  }
  public CertificateRequestSpecBuilder(CertificateRequestSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withCsr(instance.getCsr()); 
    this.withDuration(instance.getDuration()); 
    this.withIsCA(instance.getIsCA()); 
    this.withIssuerRef(instance.getIssuerRef()); 
    this.withUsages(instance.getUsages()); 
    this.validationEnabled = validationEnabled; 
  }
  CertificateRequestSpecFluent<?> fluent;
  Boolean validationEnabled;
  public CertificateRequestSpec build() {
    CertificateRequestSpec buildable = new CertificateRequestSpec(fluent.getCsr(),fluent.getDuration(),fluent.getIsCA(),fluent.getIssuerRef(),fluent.getUsages());
    return buildable;
  }
  
}

==> certmanager-model-v1alpha2-6.4.1-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/CertificateRequestSpecBuilder.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CertificateRequestSpecBuilder extends CertificateRequestSpecFluentImpl<CertificateRequestSpecBuilder> implements VisitableBuilder<CertificateRequestSpec,CertificateRequestSpecBuilder>{
  public CertificateRequestSpecBuilder() {
    this(false);
  }
  public CertificateRequestSpecBuilder(Boolean validationEnabled) {
    this(new CertificateRequestSpec(), validationEnabled);
  }
  public CertificateRequestSpecBuilder(CertificateRequestSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public CertificateRequestSpecBuilder(CertificateRequestSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CertificateRequestSpec(), validationEnabled);
  }
  public CertificateRequestSpecBuilder(CertificateRequestSpecFluent<?> fluent,CertificateRequestSpec instance) {
    this(fluent, instance, false);
  }
  public CertificateRequestSpecBuilder(CertificateRequestSpecFluent<?> fluent,CertificateRequestSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCsr(instance.getCsr()); 
    fluent.withDuration(instance.getDuration()); 
    fluent.withExtra(instance.getExtra()); 
    fluent.withGroups(instance.getGroups()); 
    fluent.withIsCA(instance.getIsCA()); 
    fluent.withIssuerRef(instance.getIssuerRef()); 
    fluent.withUid(instance.getUid()); 
    fluent.withUsages(instance.getUsages()); 
    fluent.withUsername(instance.getUsername()); 
    this.validationEnabled = validationEnabled; 
  }
  public CertificateRequestSpecBuilder(CertificateRequestSpec instance) {
    this(instance,false);
  }
  public CertificateRequestSpecBuilder(CertificateRequestSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withCsr(instance.getCsr()); 
    this.withDuration(instance.getDuration()); 
    this.withExtra(instance.getExtra()); 
    this.withGroups(instance.getGroups()); 
    this.withIsCA(instance.getIsCA()); 
    this.withIssuerRef(instance.getIssuerRef()); 
    this.withUid(instance.getUid()); 
    this.withUsages(instance.getUsages()); 
    this.withUsername(instance.getUsername()); 
    this.validationEnabled = validationEnabled; 
  }
  CertificateRequestSpecFluent<?> fluent;
  Boolean validationEnabled;
  public CertificateRequestSpec build() {
    CertificateRequestSpec buildable = new CertificateRequestSpec(fluent.getCsr(),fluent.getDuration(),fluent.getExtra(),fluent.getGroups(),fluent.getIsCA(),fluent.getIssuerRef(),fluent.getUid(),fluent.getUsages(),fluent.getUsername());
    return buildable;
  }
  
}
